@@ -3,6 +3,6 @@
 
 
 (let ((inc (lambda (x) (+ 1 x))))
-  (print (inc 2)))
+  (trace (inc 2)))
 
-(print ((lambda (x) (+ x 1)) 1))
\ No newline at end of file
+(trace ((lambda (x) (+ x 1)) 1))
\ No newline at end of file
