@@ -5,15 +5,15 @@
 ;;;  3628800
 
 ;; check if not recursion
-(let ([f (lambda (n) (print "not rec"))])
+(let ([f (lambda (n) (trace "not rec"))])
   (let ([f (lambda (n) (if (= n 0)
-			   (print "rec")
+			   (trace "rec")
 			   (f 0)))])
     (f 1)))
 
-(let ([f (lambda (n) (print "not rec"))])
+(let ([f (lambda (n) (trace "not rec"))])
   (letrec ([f (lambda (n) (if (= n 0)
-			      (print "rec")
+			      (trace "rec")
 			      (f 0)))])
     (f 1)))
 
@@ -22,11 +22,11 @@
 		 (if (<= n 1)
 		     1
 		     (* n (fact (- n 1)))))])
-  (print (fact 10)))
+  (trace (fact 10)))
 
 ;; check if define
 (define (fact n)
   (if (<= n 1)
       1
       (* n (fact (- n 1)))))
-(print (fact 10))
\ No newline at end of file
+(trace (fact 10))
\ No newline at end of file
