@@ -19,7 +19,4 @@ let _ =
        (fun _ ->
 	  ok (attr "OpGetLex" ["name","42"]) @@
 	    Code.to_xml (`GetLex 42l))
-   ]) +> run_test_tt
-
-
-
+   ]) +> run_test_tt_main
